@@ -6,13 +6,12 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
-import time
-
-import requests
+from lazysdk import lazyrequests
 import hashlib
+import urllib3
 import envx
 import json
-import urllib3
+import time
 
 
 def make_sk(
@@ -105,18 +104,19 @@ def make_sign_request(
         data['sign'] = sign_res['data']
         if verify is False:
             urllib3.disable_warnings()
-            response = requests.request(
+            return lazyrequests.lazy_requests(
                 method=data['method'],
                 url=data['url'],
                 json=data,
-                verify=False
+                verify=False,
+                return_json=True
             )
         else:
-            response = requests.request(
+            return lazyrequests.lazy_requests(
                 method=data['method'],
                 url=data['url'],
-                json=data
+                json=data,
+                return_json=True
             )
-        return response.json()
     else:
         return sign_res
